#
# spec file for package python3-mock
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-mock
Version:        2.0.0
Release:        2.6
Url:            http://www.voidspace.org.uk/python/mock/
Summary:        A Python Mocking and Patching Library for Testing
License:        BSD-2-Clause
Group:          Development/Languages/Python
Source:         https://files.pythonhosted.org/packages/source/m/mock/mock-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  python3-devel
BuildRequires:  python3-pbr >= 0.11
BuildRequires:  python3-setuptools >= 17.1
BuildRequires:  python3-six >= 1.7
BuildRequires:  python3-unittest2
Requires:       python3-pbr >= 0.11
Requires:       python3-six >= 1.7
Requires:       python3-unittest2
BuildArch:      noarch

%description
mock is a Python module that provides a core Mock class. It removes the need
to create a host of stubs throughout your test suite. After performing an
action, you can make assertions about which methods / attributes were used and
arguments they were called with. You can also specify return values and set
needed attributes in the normal way.

%prep
%setup -q -n mock-%{version}

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}

%check
unit2

%files
%defattr(-,root,root,-)
%doc AUTHORS ChangeLog LICENSE.txt NEWS README.rst
%{python3_sitelib}/*

%changelog
* Sun May  8 2016 arun@gmx.de
- specfile:
  * changed to https for source url
  * updated source url to files.pythonhosted.org
* Sat Apr  9 2016 arun@gmx.de
- specfile:
  * update copyright year
- update to version 2.0.0:
  * Fix #338: depend on a fixed version of funcsigs
  * More 3.2 support dropping cleanup
  * Update sync point
  * Add Mock.assert_called()
  * Issue25347 - Format the error message output of mock's
    assert_has_calls method
  * Issue #22138: Fix mock.patch behavior when patching
    descriptors. Restore original values after patching
  * Issue #24857: Comparing call_args to a long sequence now correctly
    returns a boolean result instead of raising an exception
  * Issue #23004: mock_open() now reads binary data correctly when the
    type of read_data is bytes
  * Add version info in the docs
  * Update six to a version with raises_from
  * Fix #328 - handle unicode __repr__ on Python 2.x
  * Drop support for Python 3.2
  * Fix typo in docs/index.txt
  * Fix README.rst checking
  * Be clearer about Python version compat
  * Issue #295: use a setup_requires dependency
  * Improve grouping of imports in tests
  * Use six to detect python2/3 in main module
  * Use six to detect python2/3 in test modules
* Wed Nov 11 2015 hpj@urpla.net
- fix python3-setuptools version requirements (>= 17.1)
* Mon Oct 12 2015 toddrme2178@gmail.com
- Don't run tests in doc package.
* Mon Oct 12 2015 toddrme2178@gmail.com
- Split documentation into separate spec file to avoid dependency loop
  python3-mock <--> python3-Sphinx
* Sat Aug  1 2015 arun@gmx.de
- specfile:
  * update copyright year
  * include pbr, six
  * add Sphinx and setup sphinx build
  * add NEWS, Changelog, rename README.txt->README.rst
  * removed patch_fix_py34_mock_1.0.1.patch: applied upstream
  * removed mock-unittest2py27.patch
  * "rm -rf html/.doctrees" not needed anymore
- update to version 1.3.0:
  * Update sync point
  * Issue #21750: Further fixup to be styled like other mock APIs
  * Typo fix in mock.patch
- changes from version 1.2.0:
  * Revert "Issue #21750: mock_open.read_data can now be read from
    each instance, as it"
- changes from version 1.1.4:
  * Add 2.6 back to classifiers
  * Record sync point
  * Issue #21750: mock_open.read_data can now be read from each
    instance, as it could in Python 3.3
  * Issue #18622: unittest.mock.mock_open().reset_mock would recurse
    infinitely
  * Folk should test 2.6 locally too
  * Closes #279: setuptools.version is too new
  * Support python 2.6
- changes from version 1.1.3:
  * Update sync point and sync docs
  * Issue #23661: unittest.mock side_effects can now be exceptions again
  * Abort installation if the installer is using setuptools<17.1
- changes from version 1.1.2:
  * Closes #269: setup_requires pbr 1.3
- changes from version 1.1.1:
  * Closes #257: version the dependency on six
  * Rename README.txt to README.rst
- changes from version 1.1.0:
  * Make reproducing travis behaviour somewhat easier
  * Cleanup version number handling
  * Overhaul docs
  * Update docs
  * Remove stale MANIFEST.in, ignore pbr outputs
  * Convert to a package, use pbr, update metadata
  * Bump versions
  * Officially drop 2.6 support
  * Issue #23310: Fix MagicMock's initializer to work with
    __methods__. Behavior equivalent to m.configure_mock(). Patch by
    Kasia Jachim
  * Issue #23568: Add rdivmod support to MagicMock() objects
  * Issue #23581: Add matmul support to MagicMock
  * Issue #23326: Removed __ne__ implementations. Since fixing default
    __ne__ implementation in issue #21408 they are redundant
  * Issue #22823: Use set literals instead of creating a set from a
    list. Fixed an output of sets in examples
  * Closes #21270 : We now override tuple methods in mock.call objects
  * Suppress a couple more DeprecationWarnings in the test suite
  * Closes #21256: Printout of keyword args in deterministic order in mock calls
  * Removes unused varargs and varkwargs from assert_not_called()
  * Closes Issue 21262: New method assert_not_called for Mock
  * Closes Issue 21238: New keyword argument `unsafe` to Mock
  * Closes issue 21239. unittest.mock.patch.stopall() did not work
    deterministically when the same name was patched multiple times
  * Closes Issue 21222
  * Closes issue 17660. You no longer need to explicitly pass
    create=True when patching builtin names
  * Issue 17826. Setting an iterable side_effect on a mock created by
    create_autospec now works
  * Issue 20968. unittest.mock.MagicMock now supports division
  * Issue #20189: Four additional builtin types (PyTypeObject,
    PyMethodDescr_Type, _PyMethodWrapper_Type, and
    PyWrapperDescr_Type) have been modified to provide introspection
    information for builtins. Also: many additional Lib, test suite,
    and Argument Clinic fixes
  * Issue #19594: Use specific asserts in unittest tests
  * Remove shadowed test
  * Adjust comment
  * Issue #19013: add a __main__ to unittest.test.testmock to ease CLI
    invocation
  * Issue #19013: add unittest.main() epilogs to unittest.mock's own
    test modules
  * Process DEFAULT values in mock side_effect that returns iterator
  * Closes issue 17467. Add readline and readlines support to
    unittest.mock.mock_open
  * Issue #17047: remove doubled words added in 3.3 as reported by
    Serhiy Storchaka and Matthew Barnett
  * Issue #17015: When it has a spec, a Mock object now inspects its
    signature when matching calls, so that arguments can be matched
    positio nally or by name
  * Closes issue 15323. Improve failure message of
    Mock.assert_called_once_with
  * Close #14857: fix regression in references to PEP 3135 implicit
    __class__ closure variable. Reopens issue #12370, but also updates
    unitt est.mock to workaround that issue
  * Remove incorrect comment
  * Closes issue 14634. unittest.mock.create_autospec now supports
    keyword only arguments
  * unittest.mock: removed another bit of Python 2 only code
  * Adding unittest.mock documentation
  * unittest.mock: remove another piece of Python 2 specific code
  * Remove more Python 2 code from unittest.mock (obsolete function
    attributes)
  * Support subclassing unittest.mock._patch and fix various obscure
    bugs around patcher spec arguments
  * unittest.mock.MagicMock objects are now unorderable by default
  * Removed XXX from unittest.mock docstring and switch to a nicer
    try...except...finally
  * Remove more Python 2 compatibility cruft from unittest.mock
  * PEP 417: Adding unittest.mock
  * Ignore patch rejects too
  * Add NEWS
  * Add PyPy to travis
  * Issue #20189: Four additional builtin types
  * Just hard-depend on unittest2
  * Fix typo in test name
  * Some basic release process notes
  * Ignore more editor files
  * Add testrepository configuration
  * We never need sudo. Containers FTW
  * Fixup ignores
  * Iterating on .travis.yml
  * Setup Travis-CI
* Fri Jul 18 2014 toddrme2178@gmail.com
- Add patch_fix_py34_mock_1.0.1.patch: mock is not compatible with
  python 3.4.  python 3.4 has its a built-in mock package, but
  a lot of python packages still depend on the external one for
  some reason.
  Patch taken from:
  https://bugs.launchpad.net/ubuntu/+source/python-mock/+bug/1283742
* Wed Feb 12 2014 speilicke@suse.com
- Add mock-unittest2py27.patch: For py3.2+, the stdlib unittest module
  is sufficient
- Remove python-unittest2 requirement
- Use python-setuptools instead of distribute (upstreams merged)
* Mon Jul 15 2013 cfarrell@suse.com
- license update: BSD-2-Clause
  See LICENSE file
* Fri Jan 11 2013 p.drouand@gmail.com
- Initial python3 support
